<?php 
/* Plugin Name: Semi-Private Comments
Plugin URI: http://ok-cleek.com/blogs/?p=4061
Description: Masks comments so that user X can't see comments he didn't write (or that weren't from an admin).
Author: Cleek
Version: 1.0.5
Author URI: http://ok-cleek.com/blogs
*/ 
?>
<?php 

function plugin_is_spc_post() 
{
    global $post;
    $ispcp = get_post_meta($post->ID, '_semi_private_post', true);
    if ($ispcp=="")
    {
         $ispcp = "0"; // off
    }

    return $ispcp;
}

// ----------------------- basic operation -----------------------

function plugin_spc_get_IP() 
{
	if(!empty($_SERVER['HTTP_CLIENT_IP'])) {
		$ip_address = $_SERVER['HTTP_CLIENT_IP'] . "1";
	} else if(!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
		$ip_address = $_SERVER['HTTP_X_FORWARDED_FOR'] . "2";;
	} else if(!empty($_SERVER['REMOTE_ADDR'])) {
		$ip_address = $_SERVER['REMOTE_ADDR'] . "3";;
	} else {
		$ip_address = '';
	}
	if(strpos($ip_address, ',') !== false) {
		$ip_address = explode(',', $ip_address);
		$ip_address = $ip_address[0];
	}
	return $ip_address;
}


function plugin_spc_commentFilter($content) 
{ 
    global $comment;
    global $current_user;
    global $user_ID;
    global $post;

    $ispcp = plugin_is_spc_post();

//    return $ispcp;

    if ($ispcp!="0")
    {
        get_currentuserinfo();

        $method = get_option('spc_matching_method');
        $user_matched = 0;

        // was this comment made by the current user?
        if ($method=="User ID")
        {
            // v1.0.1 - using global user_ID, since current_user->user_ID sometimes isn't filled (?? apparently)
            // $user_matched = ($comment->user_id == $current_user->user_ID) ? 1 : 0;
            $user_matched = ($comment->user_id == $user_ID) ? 1 : 0;
        }
        else // assume $method=="IP Address")
        {
            $user_matched = ($comment->comment_author_IP == plugin_spc_get_IP()) ? 1 : 0;
        }

        // was this comment made by an admin?  1.0.5
        $admin_comment = 0;
        $com_author = new WP_User( $comment->user_id );
        if ($com_author->has_cap('edit_posts'))
        {
	          $admin_comment = 1;
        }

        if ($ispcp=="1")
        {
            if (current_user_can('edit_users') ||   // user is admin, or 
                $user_matched==1 ||                 // user is original author, or
                $admin_comment == 1)                // comment author is admin
            {
               return $content;
            }
            else
            {
               $hidden_comment_text = get_option('spc_hidden_comment_text');

               // $hidden_comment_text = $hidden_comment_text . " : " . comment_author_IP() . ", " . plugin_spc_get_IP();
               return $hidden_comment_text;
            }
        }
        else if ($ispcp=="2")
        {
            // always return hidden text, regardless of user
            $hidden_comment_text = get_option('spc_hidden_comment_text');
            return $hidden_comment_text;
        }
        else 
        {
            return $content;
        }

    }
    else
    {
        return $content;
    }
} 

add_filter('comment_text', 'plugin_spc_commentFilter'); 
add_filter('comment_text_rss', 'plugin_spc_commentFilter'); 
add_filter('comment_excerpt', 'plugin_spc_commentFilter'); 


// ----------------------- post page options -----------------------

function plugin_spc_sidebar($post) {
    $spcStatus = get_post_meta($_REQUEST['post'], '_semi_private_post', true);

    /* 1.0.2 changed to drop list, added fully-private */
    $ch0 = ""; $ch1 = ""; $ch2 = ""; $ch3 = "";
    
    if ($spcStatus=="1")
        $ch1 =" selected";
    else if ($spcStatus=="2")
        $ch2 =" selected";
    else if ($spcStatus=="3")
        $ch3 =" selected";
    else
        $ch0 =" selected";

   wp_nonce_field( plugin_basename( __FILE__ ), 'spc_noncename' );
?> 
 
  <select name="SPC_hideStyle">
    <option <?php echo $ch0; ?> value="0">Off </option>
    <option <?php echo $ch1; ?> value="1">Semi-private comments</option>
    <option <?php echo $ch2; ?> value="2">Completely private comments</option>
  </select>

 <?php 
}

function spc_meta_box_add()  
{  
   add_meta_box( 'semi_private_post_div', 'Semi-private comments', 'plugin_spc_sidebar', 'post' );  
}  

add_action( 'add_meta_boxes', 'spc_meta_box_add' );  

function plugin_spc_update_post($id) {
    // Bail if we're doing an auto save  
    if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) return; 
 
    if ( !wp_verify_nonce( $_POST['spc_noncename'], plugin_basename( __FILE__ ) ) ) return;

    if ( 'page' == $_POST['post_type'] ) 
    {
      if ( !current_user_can( 'edit_page', $post_id ) )
        return;
    }
    else
    {
      if ( !current_user_can( 'edit_post', $post_id ) )
        return;
    }
 
    $setting = "0";
    if (isset($_POST["SPC_hideStyle"]))
    {
	    $setting = $_POST["SPC_hideStyle"];
    }
    update_post_meta($id, '_semi_private_post', $setting);
}

add_action('save_post', 'plugin_spc_update_post');
add_action('edit_post', 'plugin_spc_update_post');
add_action('publish_post', 'plugin_spc_update_post');

// ------------------ options -------------------------

// default options
if (get_option('spc_options_ok') == '' || get_option('spc_options_ok') == 'NO') 
{
    delete_option('spc_hidden_comment_text');
    add_option('spc_hidden_comment_text', '<i>comment hidden</i>', 'Text to show for hidden comments', false);

    delete_option('spc_matching_method');
    add_option('spc_matching_method', 'IP Address', 'Method used to match users', false);
}

add_action('admin_menu', 'spc_plugin_menu');

function spc_plugin_menu() 
{
  add_options_page('Semi-Private Comment Options', 'Semi-Private Comments', 8, __FILE__, 'spc_plugin_options');
}

function spc_plugin_options() 
{
  if (get_option('spc_options_ok') == '')
  {
      add_option('spc_options_ok', 'YES', "SPC Comment Options Flag", false);
  }

  $method = get_option('spc_matching_method');

?>

  <div class="wrap">
  <h2>Semi-Private Comments</h2>

  <form method="post" action="options.php">
      <?php echo wp_nonce_field('update-options'); ?>
      <table class="form-table" width=100%>
          <tr valign="top">
              <th width=30% scope="row">Hidden comment text</th>
              <td><input type="text" name="spc_hidden_comment_text" value="<?php echo get_option('spc_hidden_comment_text');?>" /></td>
          </tr>
          <tr valign="top">
              <th width=30% scope="row">User matching method</th>
              <td>
                  <input type="radio" name="spc_matching_method" value="IP Address" <?php echo ($method=="IP Address") ? ('checked') : (''); ?> >IP Address<br>
                  <input type="radio" name="spc_matching_method" value="User ID" <?php echo ($method=="User ID") ? ('checked') : (''); ?> >User ID (should only be used if your commenters are registered users)<br>
              </td>
          </tr>
      </table>

      <input type="hidden" name="action" value="update" />
      <input type="hidden" name="page_options" value="spc_hidden_comment_text, spc_matching_method" />

      <p class="submit">
      <input type="submit" name="Submit" value="Save Changes" />
      </p>
  </form>
  </div>

  <?php
}
?>